#
# spec file for package hauler
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hauler
Version:        1.0.1
%global git_commit bb2a8bfbeca0f33998e0015e6f0cfeaa7ec3dc93
Release:        bp160.1.1
Summary:        Airgap Swiss Army Knife
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/rancherfederal/hauler
Source:         %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
ExclusiveArch:  x86_64 aarch64
BuildRequires:  cosign
BuildRequires:  golang-packaging
BuildRequires:  zstd
BuildRequires:  golang(API) = 1.21

%description
Rancher Government Hauler simplifies the airgap experience without requiring
users to adopt a specific workflow. Hauler simplifies the airgapping process,
by representing assets (images, charts, files, etc...) as content and
collections to allow users to easily fetch, store, package, and distribute
these assets with declarative manifests or through the command line.

Hauler does this by storing contents and collections as OCI Artifacts and
allows users to serve contents and collections with an embedded registry and
fileserver. Additionally, Hauler has the ability to store and inspect various
non-image OCI Artifacts.

%prep
%autosetup -p1 -a1

%build
export CGO_ENABLED=1
mkdir -p cmd/hauler/binaries/
%ifarch aarch64
cp -p %{_bindir}/cosign cmd/hauler/binaries/cosign-linux-arm64
%endif
%ifarch x86_64
cp -p %{_bindir}/cosign cmd/hauler/binaries/cosign-linux-amd64
%endif
# s -w -X {{ .Env.vpkg }}.gitVersion={{ .Version }} -X {{ .Env.vpkg }}.gitCommit={{ .ShortCommit }} -X {{ .Env.vpkg }}.gitTreeState={{if .IsGitDirty}}dirty{{else}}clean{{end}} -X {{ .Env.vpkg }}.buildDate={{ .Date }}
go build -o hauler -mod=vendor -buildmode=pie -trimpath -ldflags "-s -w -X github.com/rancherfederal/hauler/internal/version.gitVersion=%{version} \
    -X github.com/rancherfederal/hauler/internal/version.gitCommit=%{git_commit} \
    -X github.com/rancherfederal/hauler/internal/version.gitTreeState=clean" cmd/hauler/main.go

%install
install -D -m 755 hauler %{buildroot}/%{_bindir}/%{name}

%files
%doc README.md
%{_bindir}/%{name}

%changelog
* Tue Apr  2 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Fix --name option in "store add file" command
  * Bump helm.sh/helm/v3 from 3.14.1 to 3.14.2
  * Exit with status code 1 if cosign is not configured
  * fix exit code on error @amartin120
  * add registry flag to cli for sync @amartin120
- update to 1.0.0:
  * adding graphics @bgulla
  * updated readme and removed roadmap @zackbradys
  * updated/cleaned up install.sh @zackbradys
  * remove deprecated commands @amartin120
  * Bump helm.sh/helm/v3 from 3.14.0 to 3.14.1
  * bug-fix: handle complex file names @amartin120
  * add login command @amartin120
  * update to add size totals and cosign bits to the info
- update to 0.4.4:
  * add annotations for registry @amartin120
  * add annotations for key and platform @amartin120
  * Flags passed from the CLI have a global effect on any image
    UNLESS it has a (key/platform) specified on the individual
    image. Individual image key/platform takes precedence.
  * If you have `hauler.dev/key` and/or `hauler.dev/platform` at
    the annotation level, it would work just like the CLI flag
    and globally apply for everything except individual images
    specifying otherwise.  Just like above.
  * If you just so happen to provide both an annotation AND the
    CLI flag for the same thing, the CLI flag wins.
  * As for the `hauler.dev/registry` annotation, it will apply
    globally unless the provided image reference already has a
    registry specified in its name.
- update to 0.4.3:
  * dep bumps for security vuln fixes @amartin120
  * check tag to determine pre-release @amartin120
  * Update install.sh for file cleaning @clemenko
  * add platform flag for image add and sync @amartin120
  * bump cosign version to v2.2.2+carbide.2 @amartin120
  * improve cosign setup @amartin120
  * updated archive default name @zackbradys
  * add license file @amartin120
  * adjust to make registry and fileserver subcommands
  * add fileserver option for `store serve` @amartin120
* Tue Apr  2 2024 dmueller@suse.com
- Update to version 1.0.1:
  * Fix --name option in "store add file" command
  * Bump helm.sh/helm/v3 from 3.14.1 to 3.14.2
  * Exit with status code 1 if cosign is not configured
  * reverting changes for logos (#189)
  * adding graphics
  * fix exit code on error
  * add registry flag to cli for sync
  * updated readme and removed roadmap
  * updated/cleaned up install.sh
  * remove deprecated commands
  * Bump helm.sh/helm/v3 from 3.14.0 to 3.14.1
  * bug-fix: handle complex file names
  * add login command
  * update to add size totals and cosign bits to the info command
  * switch the 'apply the registry override first in a image sync
  * switch the 'not a multi-arch image' log message to be debug
  * fix whitspace issue
  * add better logging for save
  * add annotations for registry
  * add annotations for key and platform
  * dep bumps for security vuln fixes
  * check tag to determine pre-release
  * Update install.sh
  * Update install.sh for file cleaning
  * clean up makefile
  * remove extra debug statement
  * another fix for the unit test gh action
  * add platform flag for image add and sync
  * adjust unit test gh action for latest updates
  * bump cosign version to v2.2.2+carbide.2
  * improve cosign setup
  * updated archive default name
  * add license file
  * adjust to make registry and fileserver subcommands
  * add fileserver option for `store serve`
  * added homebrew install instructions
  * updated hauler version and automated default version
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- Initial package (0.4.2)
